pub struct EntropyFixture { /* private fields */ }Expand description
Handle used to derive deterministic high-entropy byte fixtures.
Implementations
Sourceimpl EntropyFixture
impl EntropyFixture
Sourcepub fn bytes(&self, len: usize) -> Vec<u8> ⓘ
pub fn bytes(&self, len: usize) -> Vec<u8> ⓘ
Returns a deterministic byte buffer of the requested length.
Sourcepub fn bytes_with_variant(
&self,
len: usize,
variant: impl AsRef<str>,
) -> Vec<u8> ⓘ
pub fn bytes_with_variant( &self, len: usize, variant: impl AsRef<str>, ) -> Vec<u8> ⓘ
Returns a deterministic byte buffer for an explicit variant.
Sourcepub fn fill_bytes(&self, dest: &mut [u8])
pub fn fill_bytes(&self, dest: &mut [u8])
Fill an existing buffer with deterministic entropy.
Sourcepub fn fill_bytes_with_variant(&self, dest: &mut [u8], variant: impl AsRef<str>)
pub fn fill_bytes_with_variant(&self, dest: &mut [u8], variant: impl AsRef<str>)
Fill an existing buffer with deterministic entropy for an explicit variant.