EntropyFactoryExt

Trait EntropyFactoryExt 

pub trait EntropyFactoryExt {
    // Required methods
    fn entropy(&self, label: impl AsRef<str>) -> EntropyFixture;
    fn entropy_with_variant(
        &self,
        label: impl AsRef<str>,
        variant: impl AsRef<str>,
    ) -> EntropyFixture;
}
Extension trait to hang entropy helpers off the core Factory.

Required Methods

fn entropy(&self, label: impl AsRef<str>) -> EntropyFixture

Create an entropy fixture handle for a label.

fn entropy_with_variant( &self, label: impl AsRef<str>, variant: impl AsRef<str>, ) -> EntropyFixture

Create an entropy fixture handle with a custom variant.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl EntropyFactoryExt for Factory

Source

fn entropy(&self, label: impl AsRef<str>) -> EntropyFixture

Source

fn entropy_with_variant( &self, label: impl AsRef<str>, variant: impl AsRef<str>, ) -> EntropyFixture

Implementors