pub trait EntropyFactoryExt {
// Required methods
fn entropy(&self, label: impl AsRef<str>) -> EntropyFixture;
fn entropy_with_variant(
&self,
label: impl AsRef<str>,
variant: impl AsRef<str>,
) -> EntropyFixture;
}Expand description
Extension trait to hang entropy helpers off the core Factory.
Required Methods
Sourcefn entropy(&self, label: impl AsRef<str>) -> EntropyFixture
fn entropy(&self, label: impl AsRef<str>) -> EntropyFixture
Create an entropy fixture handle for a label.
Sourcefn entropy_with_variant(
&self,
label: impl AsRef<str>,
variant: impl AsRef<str>,
) -> EntropyFixture
fn entropy_with_variant( &self, label: impl AsRef<str>, variant: impl AsRef<str>, ) -> EntropyFixture
Create an entropy fixture handle with a custom variant.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".